@@ -23,7 +23,6 @@
 
 #include "gconf-editor-application.h"
 #include "gconf-stock-icons.h"
-#include "gconf-message-dialog.h"
 #include "gconf-editor-window.h"
 
 
@@ -51,7 +50,7 @@ invalid_arg_error_dialog (GtkWindow  *parent,
 gint
 main (gint argc, gchar **argv)
 {
-	GtkWidget *window, *dialog;
+	GtkWidget *window;
 
 	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
@@ -79,20 +78,7 @@ main (gint argc, gchar **argv)
 			g_free (reason);
 		}
 	}
-	
-	/* Put up a caveat dialog */
-	if (gconf_message_dialog_should_show ("caveat-dialog")) {
-		dialog = gconf_message_dialog_new (GTK_WINDOW (window), 0,
-						   GTK_MESSAGE_WARNING,
-						   GTK_BUTTONS_OK,
-						   "caveat-dialog",
-						   _("This tool allows you to directly edit your configuration database. "
-						     "This is not the recommended way of setting desktop preferences. "
-						     "Use this tool at your own risk."));
-		gtk_dialog_run (GTK_DIALOG (dialog));
-		gtk_widget_destroy (dialog);
-	}
-	
+
 	gtk_main ();
 	
 	return 0;
